package ics332.rc.v2;

import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

import ics332.rc.common.AbstractCounter;

/**
 * A thread-safe counter implementation using a spin lock
 */
public class Counter extends AbstractCounter {
	private Lock lock;
	public Counter(int initialCounterValue, boolean debug) {
		super(initialCounterValue, debug);
		this.lock = new ReentrantLock();
	}
	
	public void increment() {
		while (!lock.tryLock()) {
			;
		}
		if (debug) {
			System.out.println("Before increment: " + this.counterValue);
		}
		this.counterValue += 1;
		if (debug) {
			System.out.println(" After increment: " + this.counterValue);
		}
		lock.unlock();
	}
	public void decrement() {
		while (!lock.tryLock()) {
			;
		}
		if (debug) {
			System.out.println("Before decrement: " + this.counterValue);
		}
		this.counterValue -= 1;
		if (debug) {
			System.out.println(" After decrement: " + this.counterValue);
		}
		lock.unlock();
	}
}
