package ics332.rc.v6;

import java.util.concurrent.atomic.AtomicInteger;

import ics332.rc.common.AbstractCounter;

/**
 * A thread-safe counter implementation: use atomics!
 */
public class Counter extends AbstractCounter {
	private AtomicInteger atomicCounter;
	
	public Counter(int initialCounterValue, boolean debug) {
		super(initialCounterValue, debug); // The 
		this.atomicCounter = new AtomicInteger(initialCounterValue);
	}
	@Override
	public int getCounterValue() {
		return this.atomicCounter.intValue();
	}
	
	public void increment() {
		if (debug) {
			System.out.println("Before increment: " + this.counterValue);
		}
		this.atomicCounter.incrementAndGet();
		if (debug) {
			System.out.println(" After increment: " + this.counterValue);
		}
	}
	public void decrement() {
		if (debug) {
			System.out.println("Before decrement: " + this.counterValue);
		}
		this.atomicCounter.decrementAndGet();
		if (debug) {
			System.out.println(" After decrement: " + this.counterValue);
		}
	}
}
